=======
pyacorn
=======

.. image:: https://www.squirreltechnologies.nz/assets/img/logo.png
  :height: 80
  :target: https://www.squirreltechnologies.nz/
  
Getting started is just one ``pip install`` away

.. code-block:: shell-session

   # 1) install the acorn python client
   pip3 install pyacorn

   # 2) login and select a project
   # Store temporary credentials in netrc
   pyacorn login

   # View the available projects
   pyacorn list

   # 3) prepare your workspace
   pyacorn grow <project id>

   # If you are on Windows and having PATH problems:
   py -3 -m pyacorn login
   py -3 -m pyacorn list
   py -3 -m pyacorn grow <project id>


Frequently Asked Questions
==========================

What is acorn anyway?
---------------------

A new platform for engineering the future. We want to make software simpler, and acorn is our vision of how to achieve that aim. Alpha testing has begun...

Learn more at `Squirrel Technologies Ltd. <https://squirreltechnologies.nz/>`_.

Links
=======

* Web portal: `acorn <https://acorn.squirreltechnologies.nz/>`_.
* Company website: `Squirrel Technologies Ltd. <https://squirreltechnologies.nz/>`_.
* Email: `info@squirreltechnologies.nz <mailto:info@squirreltechnologies.nz>`_.

We are happy to help if you have any questions. Please email our support at `support@squirreltechnologies.nz <mailto:support@squirreltechnologies.nz>`_.